@@ -121,7 +121,10 @@ err:
 /* This function parses /etc/fstab using getmntent() and uses other tricks
  * to fill in the info for all filesystems with the 'pamconsole' option...
  * unless, of course getuid() == 0, then we get them all.  No reason root
- * shouldn't be allowed to use this, right?.  */
+ * shouldn't be allowed to use this, right?.
+ *
+ * Returns a linked list, on unrecoverable error shows a dialog and exits.
+ */
 static struct mountinfo *
 build_mountinfo_list(void)
 {
@@ -139,8 +142,22 @@ build_mountinfo_list(void)
 	/* Open the /etc/fstab file (yes, the preprocessor define is named
 	 * with an "m", don't let that throw you. */
 	fstab = setmntent(_PATH_MNTTAB, "r");
-	ret = NULL;
+	if (fstab == NULL) {
+		GtkWidget *dialog;
+		int err;
 
+		err = errno;
+		dialog = create_error_box(_("Error loading list of file "
+					    "systems"), _("User Mount Tool"));
+		gtk_message_dialog_format_secondary_text
+			(GTK_MESSAGE_DIALOG(dialog), "%s", strerror(err));
+
+		gtk_dialog_run(GTK_DIALOG(dialog));
+		gtk_widget_destroy(dialog);
+		exit(EXIT_FAILURE);
+	}
+
+	ret = NULL;
 	/* Iterate over all of the entries. */
 	while((fstab_entry = getmntent(fstab)) != NULL) {
 		struct stat dev_st;
@@ -315,7 +332,7 @@ format(struct mountinfo *info)
 		mkfs = g_strconcat(sbindir, "/mkfs.*", NULL);
 		g_free(sbindir);
 
-		options = gtk_combo_box_new_text();
+		options = gtk_combo_box_text_new();
 
 		defaultfs = 0;
 		results_valid = glob(mkfs, 0, NULL, &results) == 0;
@@ -325,8 +342,8 @@ format(struct mountinfo *info)
 			const char *text;
 
 			text = results.gl_pathv[i] + strlen(mkfs) - 1;
-			gtk_combo_box_append_text(GTK_COMBO_BOX(options),
-						  text);
+			gtk_combo_box_text_append_text
+				(GTK_COMBO_BOX_TEXT(options), text);
 			if(strcmp(text, PREFERRED_FS) == 0)
 				defaultfs = i;
 		}
@@ -446,11 +463,11 @@ response_callback(GtkWidget *emitter, gint response, gpointer user_data)
 			/* Format. */
 			g_return_if_fail(info != NULL);
 			toplevel = gtk_widget_get_toplevel(emitter);
-			if (GTK_WIDGET_TOPLEVEL(toplevel)) {
+			if (gtk_widget_is_toplevel(toplevel)) {
 				gtk_widget_set_sensitive(toplevel, FALSE);
 			}
 			format(info);
-			if (GTK_WIDGET_TOPLEVEL(toplevel)) {
+			if (gtk_widget_is_toplevel(toplevel)) {
 				gtk_widget_set_sensitive(toplevel, TRUE);
 			}
 			break;
